verifyM2MTokenWithHttpInfo method
Verify a M2M Token
Verifies a M2M Token. This endpoint can be authenticated by either a Machine Secret Key or by a Clerk Secret Key. - When verifying a M2M Token with a Machine Secret Key, the token must be granted access to the Machine associated with the Machine Secret Key. - When verifying a M2M Token with a Clerk Secret Key, any token on the Instance can be verified.
Note: This method returns the HTTP Response.
Parameters:
- VerifyM2MTokenRequest verifyM2MTokenRequest (required):
Implementation
Future<http.Response> verifyM2MTokenWithHttpInfo(
VerifyM2MTokenRequest verifyM2MTokenRequest,
) async {
// ignore: prefer_const_declarations
final path = r'/m2m_tokens/verify';
// ignore: prefer_final_locals
Object? postBody = verifyM2MTokenRequest;
final queryParams = <QueryParam>[];
final headerParams = <String, String>{};
final formParams = <String, String>{};
const contentTypes = <String>['application/json'];
return apiClient.invokeAPI(
path,
'POST',
queryParams,
postBody,
headerParams,
formParams,
contentTypes.isEmpty ? null : contentTypes.first,
);
}